@@ -36,7 +36,7 @@
     Md => "M/d",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
+    hm => "h:mm\N{U+202f}a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
@@ -263,10 +263,10 @@
   ],
   script => undef,
   territory => "Ghana",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 41,
+  version => 42,
 }
