@@ -36,7 +36,7 @@
     Md => "M/d",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
+    hm => "h:mm\N{U+202f}a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
@@ -268,5 +268,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
