@@ -19,7 +19,7 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM, y G",
     GyMMMd => "d MMM, y G",
-    GyMd => "GGGGG dd-MM-y",
+    GyMd => "dd-MM-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -143,15 +143,15 @@
     "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}",
     "\N{U+09ab}\N{U+09c7}\N{U+09ac}",
     "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
-    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b2}",
+    "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}",
     "\N{U+09ae}\N{U+09c7}",
     "\N{U+099c}\N{U+09c1}\N{U+09a8}",
-    "\N{U+099c}\N{U+09c1}\N{U+09b2}\N{U+09be}\N{U+0987}",
-    "\N{U+0986}\N{U+0997}\N{U+09b8}\N{U+09cd}\N{U+099f}",
-    "\N{U+09b8}\N{U+09c7}\N{U+09aa}\N{U+09cd}\N{U+099f}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
-    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}\N{U+09ac}\N{U+09b0}",
-    "\N{U+09a8}\N{U+09ad}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
-    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
+    "\N{U+099c}\N{U+09c1}\N{U+09b2}",
+    "\N{U+0986}\N{U+0997}",
+    "\N{U+09b8}\N{U+09c7}\N{U+09aa}",
+    "\N{U+0985}\N{U+0995}\N{U+09cd}\N{U+099f}\N{U+09cb}",
+    "\N{U+09a8}\N{U+09ad}\N{U+09c7}",
+    "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}",
   ],
   month_format_narrow => [
     "\N{U+099c}\N{U+09be}",
@@ -182,8 +182,8 @@
     "\N{U+09a1}\N{U+09bf}\N{U+09b8}\N{U+09c7}\N{U+09ae}\N{U+09cd}\N{U+09ac}\N{U+09b0}",
   ],
   month_stand_alone_abbreviated => [
-    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
-    "\N{U+09ab}\N{U+09c7}\N{U+09ac}\N{U+09cd}\N{U+09b0}\N{U+09c1}\N{U+09af}\N{U+09bc}\N{U+09be}\N{U+09b0}\N{U+09c0}",
+    "\N{U+099c}\N{U+09be}\N{U+09a8}\N{U+09c1}",
+    "\N{U+09ab}\N{U+09c7}\N{U+09ac}",
     "\N{U+09ae}\N{U+09be}\N{U+09b0}\N{U+09cd}\N{U+099a}",
     "\N{U+098f}\N{U+09aa}\N{U+09cd}\N{U+09b0}\N{U+09bf}\N{U+09b2}",
     "\N{U+09ae}\N{U+09c7}",
@@ -272,5 +272,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 41,
+  version => 42,
 }
