@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "a.\N{U+00a0}m.",
-    "p.\N{U+00a0}m.",
+    "a.\N{U+202f}m.",
+    "p.\N{U+202f}m.",
   ],
   available_formats => {
     Bh => "h B",
@@ -13,8 +13,8 @@
     EHm => "E H:mm",
     EHms => "E H:mm:ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
     GyMMMEd => "E, d MMM 'de' y G",
@@ -41,13 +41,13 @@
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmsvvvv => "h:mm:ss a (vvvv)",
-    hmv => "h:mm a v",
-    hmvvvv => "h:mm a (vvvv)",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
+    hmv => "h:mm\N{U+202f}a v",
+    hmvvvv => "h:mm\N{U+202f}a (vvvv)",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
@@ -69,8 +69,8 @@
   date_format_long => "d MMMM 'de' y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
-  datetime_format_full => "{1}, 'a' 'les' {0}",
-  datetime_format_long => "{1}, 'a' 'les' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
@@ -279,5 +279,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
