@@ -13,13 +13,13 @@
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E, d.",
-    Ehm => "E h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d. MMM y G",
     GyMMMd => "d. MMM y G",
-    GyMd => "dd.MM.y GGGGG",
+    GyMd => "dd.MM.y G",
     H => "HH 'Uhr'",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -39,13 +39,13 @@
     Md => "d.M.",
     d => "d",
     h => "h 'Uhr' a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
-    yM => "M.y",
+    yM => "MM/y",
     yMEd => "E, d.M.y",
     yMM => "MM.y",
     yMMM => "MMM y",
@@ -64,8 +64,8 @@
   date_format_long => "d. MMMM y",
   date_format_medium => "dd.MM.y",
   date_format_short => "dd.MM.yy",
-  datetime_format_full => "{1} 'um' {0}",
-  datetime_format_long => "{1} 'um' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -274,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 40,
+  version => 42,
 }
