@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "a.\N{U+00a0}m.",
-    "p.\N{U+00a0}m.",
+    "a.\N{U+202f}m.",
+    "p.\N{U+202f}m.",
   ],
   available_formats => {
     Bh => "h B",
@@ -13,8 +13,8 @@
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E d",
-    Ehm => "E, h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E, h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -22,12 +22,13 @@
     GyMMMMEd => "E, d 'de' MMMM 'de' y G",
     GyMMMMd => "d 'de' MMMM 'de' y G",
     GyMMMd => "d 'de' MMM 'de' y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
-    Hmsv => "H:mm:ss v",
-    Hmsvvvv => "H:mm:ss (vvvv)",
-    Hmv => "H:mm v",
+    Hmsv => "HH:mm:ss v",
+    Hmsvvvv => "HH:mm:ss vvvv",
+    Hmv => "HH:mm v",
     M => "L",
     MEd => "E, d/M",
     MMM => "LLL",
@@ -42,23 +43,23 @@
     MMdd => "d/M",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmsvvvv => "h:mm:ss a (vvvv)",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
     yMEd => "E d/M/y",
     yMM => "M/y",
-    yMMM => "MMM 'de' y",
-    yMMMEd => "E, d 'de' MMM 'de' y",
+    yMMM => "MMM y",
+    yMMMEd => "E, d MMM y",
     yMMMM => "MMMM 'de' y",
     yMMMMEd => "EEE, d 'de' MMMM 'de' y",
     yMMMMd => "d 'de' MMMM 'de' y",
-    yMMMd => "d 'de' MMM 'de' y",
+    yMMMd => "d MMM y",
     yMd => "d/M/y",
     yQQQ => "QQQ 'de' y",
     yQQQQ => "QQQQ 'de' y",
@@ -73,7 +74,7 @@
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "lun",
     "mar",
@@ -84,13 +85,13 @@
     "dom",
   ],
   day_format_narrow => [
-    "l",
-    "m",
-    "m",
-    "j",
-    "v",
-    "s",
-    "d",
+    "L",
+    "M",
+    "M",
+    "J",
+    "V",
+    "S",
+    "D",
   ],
   day_format_wide => [
     "lunes",
@@ -102,13 +103,13 @@
     "domingo",
   ],
   day_stand_alone_abbreviated => [
-    "lun.",
-    "mar.",
-    "mi\N{U+00e9}.",
-    "jue.",
-    "vie.",
-    "s\N{U+00e1}b.",
-    "dom.",
+    "lun",
+    "mar",
+    "mi\N{U+00e9}",
+    "jue",
+    "vie",
+    "s\N{U+00e1}b",
+    "dom",
   ],
   day_stand_alone_narrow => [
     "L",
@@ -129,12 +130,12 @@
     "domingo",
   ],
   era_abbreviated => [
-    "a. C.",
-    "d. C.",
+    "a.C.",
+    "d.C.",
   ],
   era_narrow => [
-    "a. C.",
-    "d. C.",
+    "a.C.",
+    "d.C.",
   ],
   era_wide => [
     "antes de Cristo",
@@ -148,18 +149,18 @@
   glibc_time_format => "%H:%M:%S",
   language => "Spanish",
   month_format_abbreviated => [
-    "ene.",
-    "feb.",
-    "mar.",
-    "abr.",
-    "may.",
-    "jun.",
-    "jul.",
-    "ago.",
-    "sep.",
-    "oct.",
-    "nov.",
-    "dic.",
+    "ene",
+    "feb",
+    "mar",
+    "abr",
+    "may",
+    "jun",
+    "jul",
+    "ago",
+    "sept",
+    "oct",
+    "nov",
+    "dic",
   ],
   month_format_narrow => [
     "E",
@@ -190,18 +191,18 @@
     "diciembre",
   ],
   month_stand_alone_abbreviated => [
-    "ene.",
-    "feb.",
-    "mar.",
-    "abr.",
-    "may.",
-    "jun.",
-    "jul.",
-    "ago.",
-    "sep.",
-    "oct.",
-    "nov.",
-    "dic.",
+    "ene",
+    "feb",
+    "mar",
+    "abr",
+    "may",
+    "jun",
+    "jul",
+    "ago",
+    "sept",
+    "oct",
+    "nov",
+    "dic",
   ],
   month_stand_alone_narrow => [
     "E",
@@ -280,5 +281,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 39,
+  version => 42,
 }
