@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "a.\N{U+00a0}m.",
-    "p.\N{U+00a0}m.",
+    "a.\N{U+202f}m.",
+    "p.\N{U+202f}m.",
   ],
   available_formats => {
     Bh => "h B",
@@ -13,8 +13,8 @@
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E d",
-    Ehm => "E, h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E, h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -43,12 +43,12 @@
     MMdd => "d/M",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmsvvvv => "h:mm:ss a (vvvv)",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
@@ -85,13 +85,13 @@
     "dom",
   ],
   day_format_narrow => [
-    "l",
-    "m",
-    "m",
-    "j",
-    "v",
-    "s",
-    "d",
+    "L",
+    "M",
+    "M",
+    "J",
+    "V",
+    "S",
+    "D",
   ],
   day_format_wide => [
     "lunes",
@@ -130,12 +130,12 @@
     "domingo",
   ],
   era_abbreviated => [
-    "a. C.",
-    "d. C.",
+    "a.C.",
+    "d.C.",
   ],
   era_narrow => [
-    "a. C.",
-    "d. C.",
+    "a.C.",
+    "d.C.",
   ],
   era_wide => [
     "antes de Cristo",
@@ -281,5 +281,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
