@@ -14,12 +14,12 @@
     EHms => "E HH:mm:ss",
     Ed => "E, d",
     Ehm => "E h:mma",
-    Ehms => "E h:mm:ss a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
-    GyMd => "d/M/y GGGGG",
+    GyMd => "d/M/y G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -40,8 +40,8 @@
     d => "d",
     h => "ha",
     hm => "h:mma",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
     hmv => "h:mma v",
     ms => "mm:ss",
     y => "y",
@@ -275,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
