@@ -13,8 +13,8 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d., E",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "G y.",
     GyMMM => "G y. MMM",
     GyMMMEd => "G y. MMM d., E",
@@ -35,11 +35,11 @@
     MMMd => "MMM d.",
     Md => "M. d.",
     d => "d",
-    h => "a h",
-    hm => "a h:mm",
-    hms => "a h:mm:ss",
-    hmsv => "a h:mm:ss v",
-    hmv => "a h:mm v",
+    h => "a\N{U+202f}h",
+    hm => "a\N{U+202f}h:mm",
+    hms => "a\N{U+202f}h:mm:ss",
+    hmsv => "a\N{U+202f}h:mm:ss v",
+    hmv => "a\N{U+202f}h:mm v",
     mmss => "mm:ss",
     ms => "mm:ss",
     y => "y.",
@@ -270,5 +270,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
