@@ -30,7 +30,8 @@
     MMM => "LLL",
     MMMEd => "E, MMM d",
     MMMMEd => "E, MMMM d",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-one" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W \N{U+0627}\N{U+0632} MMMM",
+    "MMMMW-count-other" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W \N{U+0627}\N{U+0632} MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
@@ -51,15 +52,16 @@
     yMd => "M/d/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-one" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} w \N{U+0627}\N{U+0632} Y",
+    "yw-count-other" => "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} w \N{U+0627}\N{U+0632} Y",
   },
   code => "ks-Arab-IN",
   date_format_full => "EEEE, MMMM d, y",
   date_format_long => "MMMM d, y",
   date_format_medium => "MMM d, y",
   date_format_short => "M/d/yy",
-  datetime_format_full => "{0} \N{U+067e}\N{U+066e}\N{U+06ea}\N{U+0679}\N{U+06be}\N{U+06cd} {1}",
-  datetime_format_long => "{0} \N{U+067e}\N{U+066e}\N{U+06ea}\N{U+0679}\N{U+06be}\N{U+06cd} {1}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -126,7 +128,7 @@
   ],
   era_wide => [
     "\N{U+0642}\N{U+0628}\N{U+0655}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+06cc}\N{U+0656}\N{U+062d}",
-    "\N{U+0639}\N{U+06cc}\N{U+0656}\N{U+0633}\N{U+0648}\N{U+06cc} \N{U+0633}\N{U+0646}\N{U+06c1}\N{U+0655}",
+    "\N{U+0627}\N{U+06cc}\N{U+0646}\N{U+0648} \N{U+0688}\N{U+0648}\N{U+0645}\N{U+0646}\N{U+06cc}",
   ],
   first_day_of_week => 7,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -221,8 +223,8 @@
   ],
   name => "Kashmiri India Arabic",
   native_language => "\N{U+06a9}\N{U+0672}\N{U+0634}\N{U+064f}\N{U+0631}",
-  native_name => "\N{U+06a9}\N{U+0672}\N{U+0634}\N{U+064f}\N{U+0631} \N{U+06c1}\N{U+0650}\N{U+0646}\N{U+062f}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646} \N{U+0627}\N{U+064e}\N{U+0631}\N{U+0628}\N{U+06cc}",
-  native_script => "\N{U+0627}\N{U+064e}\N{U+0631}\N{U+0628}\N{U+06cc}",
+  native_name => "\N{U+06a9}\N{U+0672}\N{U+0634}\N{U+064f}\N{U+0631} \N{U+06c1}\N{U+0650}\N{U+0646}\N{U+062f}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646} \N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
+  native_script => "\N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
   native_territory => "\N{U+06c1}\N{U+0650}\N{U+0646}\N{U+062f}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
   native_variant => undef,
   quarter_format_abbreviated => [
@@ -268,5 +270,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 41,
+  version => 42,
 }
