@@ -12,9 +12,9 @@
     EBhms => "E h:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d E",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ed => "E, d",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -37,22 +37,22 @@
     Md => "d.M",
     Mdd => "d.M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M.y",
     yMEd => "E, d.M.y",
-    yMMM => "MMM y '\N{U+0433}'.",
-    yMMMEd => "E, d MMM y '\N{U+0433}'.",
-    yMMMM => "MMMM y '\N{U+0433}'.",
-    yMMMd => "d MMM y '\N{U+0433}'.",
+    yMMM => "MMM y\N{U+202f}'\N{U+0433}'.",
+    yMMMEd => "E, d MMM y\N{U+202f}'\N{U+0433}'.",
+    yMMMM => "MMMM y\N{U+202f}'\N{U+0433}'.",
+    yMMMd => "d MMM y\N{U+202f}'\N{U+0433}'.",
     yMd => "d.M.y",
-    yQQQ => "QQQ y '\N{U+0433}'.",
-    yQQQQ => "QQQQ y '\N{U+0433}'.",
+    yQQQ => "QQQ y\N{U+202f}'\N{U+0433}'.",
+    yQQQQ => "QQQQ y\N{U+202f}'\N{U+0433}'.",
     "yw-count-one" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
     "yw-count-other" => "w. '\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+043e}\N{U+0434}' Y",
   },
@@ -61,10 +61,10 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d.M.y",
   date_format_short => "d.M.yy",
-  datetime_format_full => "{1}, '\N{U+0432}\N{U+043e}' {0}",
-  datetime_format_long => "{1}, '\N{U+0432}\N{U+043e}' {0}",
-  datetime_format_medium => "{1}, '\N{U+0432}\N{U+043e}' {0}",
-  datetime_format_short => "{1}, '\N{U+0432}\N{U+043e}' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "\N{U+043f}\N{U+043e}\N{U+043d}.",
     "\N{U+0432}\N{U+0442}\N{U+043e}.",
@@ -229,10 +229,10 @@
   native_territory => undef,
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+0458}\N{U+0430}\N{U+043d}-\N{U+043c}\N{U+0430}\N{U+0440}",
-    "\N{U+0430}\N{U+043f}\N{U+0440}-\N{U+0458}\N{U+0443}\N{U+043d}",
-    "\N{U+0458}\N{U+0443}\N{U+043b}-\N{U+0441}\N{U+0435}\N{U+043f}",
-    "\N{U+043e}\N{U+043a}\N{U+0442}-\N{U+0434}\N{U+0435}\N{U+043a}",
+    "\N{U+0458}\N{U+0430}\N{U+043d} \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}",
+    "\N{U+0430}\N{U+043f}\N{U+0440} \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}",
+    "\N{U+0458}\N{U+0443}\N{U+043b} \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}",
+    "\N{U+043e}\N{U+043a}\N{U+0442} \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}",
   ],
   quarter_format_narrow => [
     1,
@@ -241,16 +241,16 @@
     4,
   ],
   quarter_format_wide => [
-    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+0458}\N{U+0430}\N{U+043d}-\N{U+043c}\N{U+0430}\N{U+0440}",
-    "\N{U+0430}\N{U+043f}\N{U+0440}-\N{U+0458}\N{U+0443}\N{U+043d}",
-    "\N{U+0458}\N{U+0443}\N{U+043b}-\N{U+0441}\N{U+0435}\N{U+043f}",
-    "\N{U+043e}\N{U+043a}\N{U+0442}-\N{U+0434}\N{U+0435}\N{U+043a}",
+    "\N{U+0458}\N{U+0430}\N{U+043d} \N{U+2013} \N{U+043c}\N{U+0430}\N{U+0440}",
+    "\N{U+0430}\N{U+043f}\N{U+0440} \N{U+2013} \N{U+0458}\N{U+0443}\N{U+043d}",
+    "\N{U+0458}\N{U+0443}\N{U+043b} \N{U+2013} \N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}",
+    "\N{U+043e}\N{U+043a}\N{U+0442} \N{U+2013} \N{U+0434}\N{U+0435}\N{U+043a}",
   ],
   quarter_stand_alone_narrow => [
     1,
@@ -259,10 +259,10 @@
     4,
   ],
   quarter_stand_alone_wide => [
-    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
-    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+043e}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+043f}\N{U+0440}\N{U+0432}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0442}\N{U+0440}\N{U+0435}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
+    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+043e} \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0458}\N{U+0435}",
   ],
   script => undef,
   territory => undef,
@@ -271,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
