@@ -13,8 +13,8 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d E",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -35,11 +35,11 @@
     MMdd => "dd/MM",
     Md => "d-M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M-y",
@@ -263,10 +263,10 @@
   ],
   script => undef,
   territory => "Malaysia",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 41,
+  version => 42,
 }
