@@ -13,13 +13,13 @@
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
     Ed => "E, d",
-    Ehm => "E, h:mm a",
-    Ehms => "E, h:mm:ss a",
+    Ehm => "E, h:mm\N{U+202f}a",
+    Ehms => "E, h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM 'de' y G",
     GyMMMEd => "E, d 'de' MMM 'de' y G",
     GyMMMd => "d 'de' MMM 'de' y G",
-    GyMd => "d/M/y GGGGG",
+    GyMd => "dd/MM/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -37,11 +37,11 @@
     MMdd => "dd/MM",
     Md => "dd/MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM/y",
@@ -65,8 +65,8 @@
   date_format_long => "d 'de' MMMM 'de' y",
   date_format_medium => "dd/MM/y",
   date_format_short => "dd/MM/yy",
-  datetime_format_full => "{1} '\N{U+00e0}s' {0}",
-  datetime_format_long => "{1} '\N{U+00e0}s' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -275,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
