@@ -13,9 +13,9 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "d, E",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
-    Gy => "y '\N{U+0441}'. G",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
+    Gy => "y\N{U+202f}'\N{U+0441}'. G",
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
@@ -34,11 +34,11 @@
     MMMd => "MMM d",
     Md => "MM-dd",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "y-MM",
@@ -53,7 +53,7 @@
     "yw-count-other" => "Y '\N{U+0441}\N{U+044b}\N{U+043b}' w '\N{U+043d}\N{U+044d}\N{U+0434}\N{U+0438}\N{U+044d}\N{U+043b}\N{U+044d}\N{U+0442}\N{U+044d}'",
   },
   code => "sah",
-  date_format_full => "y '\N{U+0441}\N{U+044b}\N{U+043b}' MMMM d '\N{U+043a}\N{U+04af}\N{U+043d}\N{U+044d}', EEEE",
+  date_format_full => "y\N{U+202f}'\N{U+0441}\N{U+044b}\N{U+043b}' MMMM d '\N{U+043a}\N{U+04af}\N{U+043d}\N{U+044d}', EEEE",
   date_format_long => "y, MMMM d",
   date_format_medium => "y, MMM d",
   date_format_short => "yy/M/d",
@@ -133,7 +133,7 @@
   glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%H:%M:%S",
-  language => "Sakha",
+  language => "Yakut",
   month_format_abbreviated => [
     "\N{U+0422}\N{U+043e}\N{U+0445}\N{U+0441}",
     "\N{U+041e}\N{U+043b}\N{U+0443}\N{U+043d}",
@@ -218,7 +218,7 @@
     "\N{U+0441}\N{U+044d}\N{U+0442}\N{U+0438}\N{U+043d}\N{U+043d}\N{U+044c}\N{U+0438}",
     "\N{U+0430}\N{U+0445}\N{U+0441}\N{U+044b}\N{U+043d}\N{U+043d}\N{U+044c}\N{U+044b}",
   ],
-  name => "Sakha",
+  name => "Yakut",
   native_language => "\N{U+0441}\N{U+0430}\N{U+0445}\N{U+0430} \N{U+0442}\N{U+044b}\N{U+043b}\N{U+0430}",
   native_name => "\N{U+0441}\N{U+0430}\N{U+0445}\N{U+0430} \N{U+0442}\N{U+044b}\N{U+043b}\N{U+0430}",
   native_script => undef,
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
