@@ -13,8 +13,8 @@
     EHm => "E H.mm",
     EHms => "E H.mm.ss",
     Ed => "E d.",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
     GyMMMEd => "E, MMM d. y G",
@@ -36,11 +36,11 @@
     MMMd => "MMM d.",
     Md => "d.M.",
     d => "d",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
-    hmsv => "h.mm.ss a v",
-    hmv => "h.mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h.mm\N{U+202f}a",
+    hms => "h.mm.ss\N{U+202f}a",
+    hmsv => "h.mm.ss\N{U+202f}a v",
+    hmv => "h.mm\N{U+202f}a v",
     ms => "m.ss.",
     y => "y",
     yM => "L.y",
@@ -61,9 +61,9 @@
   date_format_long => "MMMM d. y",
   date_format_medium => "MMM d. y",
   date_format_short => "d.M.y",
-  datetime_format_full => "{1} 'tme' {0}",
-  datetime_format_long => "{1} 'tme' {0}",
-  datetime_format_medium => "{1} 'tme' {0}",
+  datetime_format_full => "{1} {0}",
+  datetime_format_long => "{1} {0}",
+  datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "vuo",
@@ -271,5 +271,5 @@
   time_format_medium => "H.mm.ss",
   time_format_short => "H.mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
