@@ -39,7 +39,7 @@
     h => "h a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
+    hmsv => "h:mm:ss\N{U+202f}a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
@@ -60,9 +60,9 @@
   date_format_long => "MMMM d, y",
   date_format_medium => "dd-MMM-y",
   date_format_short => "dd/MM/yy",
-  datetime_format_full => "{1} 'ee' {0}",
-  datetime_format_long => "{1} 'ee' {0}",
-  datetime_format_medium => "{1} 'ee' {0}",
+  datetime_format_full => "{1} {0}",
+  datetime_format_long => "{1} {0}",
+  datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "Isn",
@@ -215,11 +215,11 @@
     "May",
     "Juun",
     "Luuliyo",
-    "Ogost",
-    "Sebtembar",
+    "Ogosto",
+    "Sebteembar",
     "Oktoobar",
-    "Nofembar",
-    "Desembar",
+    "Noofeembar",
+    "Diseembar",
   ],
   name => "Somali Somalia",
   native_language => "Soomaali",
@@ -265,10 +265,10 @@
   ],
   script => undef,
   territory => "Somalia",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 41,
+  version => 42,
 }
