@@ -13,8 +13,8 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d.",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y. G",
     GyMMM => "MMM y. G",
     GyMMMEd => "E, d. MMM y. G",
@@ -26,7 +26,7 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, d.M.",
+    MEd => "E, d. M.",
     MMM => "LLL",
     MMMEd => "E d. MMM",
     MMMMEd => "E, d. MMMM",
@@ -37,24 +37,24 @@
     MMMd => "d. MMM",
     MMMdd => "dd.MMM",
     MMdd => "dd.MM.",
-    Md => "d.M.",
+    Md => "d. M.",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y.",
-    yM => "M.y.",
-    yMEd => "E, d.M.y.",
+    yM => "M. y.",
+    yMEd => "E, d. M. y.",
     yMM => "MM.y.",
     yMMM => "MMM y.",
     yMMMEd => "E, d. MMM y.",
     yMMMM => "MMMM y.",
     yMMMd => "d. MMM y.",
     yMMdd => "dd.MM.y.",
-    yMd => "d.M.y.",
+    yMd => "d. M. y.",
     yQQQ => "QQQ y.",
     yQQQQ => "QQQQ y.",
     "yw-count-few" => "w. 'sedmica' 'u' Y.",
@@ -276,5 +276,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
