@@ -13,8 +13,8 @@
     EHm => "E HH.mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -34,11 +34,11 @@
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
-    hmsv => "h.mm.ss a v",
-    hmv => "h.mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h.mm\N{U+202f}a",
+    hms => "h.mm.ss\N{U+202f}a",
+    hmsv => "h.mm.ss\N{U+202f}a v",
+    hmv => "h.mm\N{U+202f}a v",
     ms => "mm.ss",
     y => "y",
     yM => "M/y",
@@ -57,8 +57,8 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
-  datetime_format_full => "{1} 'jam' {0}",
-  datetime_format_long => "{1} 'jam' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -220,9 +220,9 @@
   ],
   name => "Sundanese Indonesia Latin",
   native_language => "Basa Sunda",
-  native_name => "Basa Sunda ID Latin",
+  native_name => "Basa Sunda Indonesia Latin",
   native_script => "Latin",
-  native_territory => "ID",
+  native_territory => "Indonesia",
   native_variant => undef,
   quarter_format_abbreviated => [
     "K1",
@@ -267,5 +267,5 @@
   time_format_medium => "H.mm.ss",
   time_format_short => "H.mm",
   variant => undef,
-  version => 41,
+  version => 42,
 }
